pub struct RepoHandle<'i> {
pub did: Did<'i>,
/* private fields */
}Expand description
handle to access data related to this repository.
Fields
did: Did<'i>Implementations
Sourceimpl<'i> RepoHandle<'i>
impl<'i> RepoHandle<'i>
Sourcepub async fn get_record(
&self,
collection: &str,
rkey: &str,
) -> Result<Option<Record>>
pub async fn get_record( &self, collection: &str, rkey: &str, ) -> Result<Option<Record>>
gets a record from this repository.
Sourcepub async fn list_records(
&self,
collection: &str,
limit: usize,
reverse: bool,
cursor: Option<&str>,
) -> Result<RecordList>
pub async fn list_records( &self, collection: &str, limit: usize, reverse: bool, cursor: Option<&str>, ) -> Result<RecordList>
lists records from this repository.
Sourcepub async fn generate_car(
&self,
) -> Result<Option<impl Stream<Item = Result<Bytes>> + Send + 'static>>
pub async fn generate_car( &self, ) -> Result<Option<impl Stream<Item = Result<Bytes>> + Send + 'static>>
generates a streaming CAR v1 response body for this repository.
returns None if the repo has no commit yet (still backfilling) or is an
unmigrated repo that does not have the necessary data to reconstruct the
root commit from.
notes
- calling this if you are using collection allowlist will always result in an error since the commit root won’t match the reconstructed CID.
- calling this for big repositories will incur more resource cost due to hydrant’s structure, the whole MST is always reconstructed.
Sourcepub async fn count_records(&self, collection: &str) -> Result<u64>
pub async fn count_records(&self, collection: &str) -> Result<u64>
gets how many records of a collection this repository has.
Sourceimpl<'i> RepoHandle<'i>
impl<'i> RepoHandle<'i>
Sourcepub async fn info(&self) -> Result<Option<RepoInfo>>
pub async fn info(&self) -> Result<Option<RepoInfo>>
fetch the current state of this repository.
returns None if hydrant has never seen this repository.
Sourcepub async fn collections(&self) -> Result<HashMap<Nsid<'static>, u64>>
pub async fn collections(&self) -> Result<HashMap<Nsid<'static>, u64>>
returns the collections of this repository and the number of records it has in each.