pub struct ReposControl(/* private fields */);Expand description
control over which repositories are tracked and access to their state.
in filter mode, a repo is only indexed if it either matches a signal or is
explicitly tracked via ReposControl::track. in full mode all repos are
indexed and tracking is implicit.
tracking a DID that hydrant has never seen enqueues an immediate backfill. tracking a DID that hydrant already knows about (but has marked untracked) re-enqueues it for backfill.
Implementations
Sourceimpl ReposControl
impl ReposControl
Sourcepub async fn resync(
&self,
dids: impl IntoIterator<Item = Did<'_>>,
) -> Result<Vec<Did<'static>>>
pub async fn resync( &self, dids: impl IntoIterator<Item = Did<'_>>, ) -> Result<Vec<Did<'static>>>
request one or more repositories to be resynced.
note that they may not immediately start backfilling if:
- other repos already filled the backfill concurrency limit,
- or there are many repos pending already.
this will also clear any error state the repo may have been in, allowing it to resync again.
Sourcepub async fn track(
&self,
dids: impl IntoIterator<Item = Did<'_>>,
) -> Result<Vec<Did<'static>>>
pub async fn track( &self, dids: impl IntoIterator<Item = Did<'_>>, ) -> Result<Vec<Did<'static>>>
explicitly track one or more repositories, enqueuing them for backfill if needed.
- if a repo is new, a fresh [
RepoState] is created and backfill is queued. - if a repo is already known but untracked, it is marked tracked and re-enqueued.
- if a repo is already tracked, this is a no-op.
Sourcepub async fn untrack(
&self,
dids: impl IntoIterator<Item = Did<'_>>,
) -> Result<Vec<Did<'static>>>
pub async fn untrack( &self, dids: impl IntoIterator<Item = Did<'_>>, ) -> Result<Vec<Did<'static>>>
stop tracking one or more repositories. hydrant will stop processing new events for them and remove them from the pending/resync queues, but existing indexed records are not deleted.
Sourceimpl ReposControl
impl ReposControl
Sourcepub fn iter(
&self,
cursor: Option<&Did<'_>>,
) -> impl Iterator<Item = Result<RepoInfo>>
pub fn iter( &self, cursor: Option<&Did<'_>>, ) -> impl Iterator<Item = Result<RepoInfo>>
iterates through all repositories, returning their state.
Sourcepub fn get<'i>(&self, did: &Did<'i>) -> RepoHandle<'i>
pub fn get<'i>(&self, did: &Did<'i>) -> RepoHandle<'i>
gets a handle for a repository to read from it.
Sourcepub async fn resolve(
&self,
repo: &AtIdentifier<'_>,
) -> Result<RepoHandle<'static>>
pub async fn resolve( &self, repo: &AtIdentifier<'_>, ) -> Result<RepoHandle<'static>>
same as ReposControl::get but allows you to pass in an identifier that can be
either a handle or a DID.